@@ -33,8 +33,7 @@ class accimJob():
     from accim.sim.accim_MultipleZone import \
         addMultipleZoneSch, \
         addCurveObj, \
-        addDetHVACobjEp91, \
-        addDetHVACobjEp94, \
+        addDetHVACobj, \
         addForscriptSchMultipleZone, \
         checkVentIsOn
     from accim.sim.accim_MultipleZone_EMS import \
@@ -52,14 +51,22 @@ class accimJob():
                  verboseMode: bool = True):
         from eppy import modeleditor
         from eppy.modeleditor import IDF
-        if EnergyPlus_version.lower() == 'ep94':
-            iddfile = 'C:/EnergyPlusV9-4-0/Energy+.idd'
-        elif EnergyPlus_version.lower() == 'ep91':
+        if EnergyPlus_version.lower() == 'ep91':
             iddfile = 'C:/EnergyPlusV9-1-0/Energy+.idd'
+        elif EnergyPlus_version.lower() == 'ep92':
+            iddfile = 'C:/EnergyPlusV9-2-0/Energy+.idd'
+        elif EnergyPlus_version.lower() == 'ep93':
+            iddfile = 'C:/EnergyPlusV9-3-0/Energy+.idd'
+        elif EnergyPlus_version.lower() == 'ep94':
+            iddfile = 'C:/EnergyPlusV9-4-0/Energy+.idd'
+        elif EnergyPlus_version.lower() == 'ep95':
+            iddfile = 'C:/EnergyPlusV9-5-0/Energy+.idd'
         else:
             raise ValueError("""EnergyPlus version not supported.\n
-                                     Only works for EnergyPlus 9.1 (enter Ep91) and
-                                     EnergyPlus 9.4 (enter Ep94) versions.""")
+                                     Only works for versions between EnergyPlus 9.1 (enter Ep91) and
+                                     EnergyPlus 9.5(enter Ep95).""")
+        if verboseMode:
+            print('IDD location is: '+iddfile)
         IDF.setiddname(iddfile)
 
         fname1 = filename_temp+'.idf'
